#!/usr/bin/env python
# encoding: utf-8


from torch.utils.data import Dataset

""" Unit tests

"""

import numpy
import torch
from torch.autograd import Variable

def test_extractors():

    # DeepPixBiS
    print('Basic')
    from ..extractor.image import DeepPixBiSExtractor
    extractor = DeepPixBiSExtractor(scoring_method="pixel_mean")
    # this architecture expects color images of size 3x224x224
    data = numpy.random.rand(3, 224, 224).astype("uint8")
    output = extractor(data)
    assert output.shape[0] == 1

    # DeepPixBiS -Mario
    from ..extractor.image import MarioDeepPixBiSExtractor
    print('Mario')

    extractor = MarioDeepPixBiSExtractor( scoring_method="pixel_mean")
    # this architecture expects multi-channel images of size num_channelsx224x224
    data = numpy.random.rand(3, 224, 224).astype("uint8")
    output = extractor.transform([data])
    assert output[0].shape[0] == 1


    # DeepPixBiS -Wrapper
    from bob.bio.base.transformers import ExtractorTransformer
    print('With Wrapper')
    from ..extractor.image import DeepPixBiSExtractor
    extractor = DeepPixBiSExtractor(scoring_method="pixel_mean")
    data = numpy.random.rand(3, 224, 224).astype("uint8")
    wrapped_extractor = ExtractorTransformer(extractor)
    output = wrapped_extractor.transform([data])
    assert output[0].shape[0] == 1




